import { DockerImageAsset } from "aws-cdk-lib/aws-ecr-assets";
import { Construct } from "constructs";
export interface WordpressDockerImageProps {
    /**
     * @default - wordpress:php8.0-apache
     */
    readonly wordpressDockerImageBase?: string;
    /**
     * This configures how much memory is given to Wordpress. It's different than container memory,
     * which is configured by `containerMemory`. See
     * https://developer.wordpress.org/apis/wp-config-php/#increasing-memory-allocated-to-php
     * for details on this setting.
     *
     * @default - 256M
     */
    readonly wordpressMemoryLimit?: string;
    /**
     * Memory to give the ECS container at runtime. See
     * https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ecs-taskdefinition.html#cfn-ecs-taskdefinition-memory
     * for details on available configurations
     *
     * @default - 512 (MB)
     */
    readonly containerMemory?: number;
    /**
     * The number of vCPU units to give the ECS container at runtime. See
     * https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ecs-taskdefinition.html#cfn-ecs-taskdefinition-cpu
     * for details on available configurations
     *
     * @default - 256 (0.25 vCPU)
     */
    readonly containerCpu?: number;
    /**
     * The version of wp2static to install. See
     * https://github.com/WP2Static/wp2static/releases for available version
     *
     * @default - 7.2
     */
    readonly wp2StaticVersion?: string;
    /**
     * @default - 1.0
     */
    readonly wp2StaticS3AddonVersion?: string;
}
export declare class WordpressDockerImage extends Construct {
    readonly dockerImageAsset: DockerImageAsset;
    readonly containerCpu: number;
    readonly containerMemory: number;
    readonly wordpressMemoryLimit: string;
    constructor(scope: Construct, id: string, props?: WordpressDockerImageProps);
    private getPhpVersionFromWordpressImage;
}
